==> haskell-edisoncore-1.3.2.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-edisoncore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: EdisonCore
version: 1.3.2.1
id: EdisonCore-1.3.2.1-6yqPau7HF7PLI1sbKMpaCS
key: EdisonCore-1.3.2.1-6yqPau7HF7PLI1sbKMpaCS
license: MIT
maintainer: robdockins AT fastmail DOT fm
author: Chris Okasaki
stability: Stable
homepage: http://rwd.rdockins.name/edison/home/
synopsis: A library of efficient, purely-functional data structures (Core Implementations)
description:
    This package provides the core Edison data structure implementations,
    including multiple sequence, set, bag, and finite map concrete
    implementations with various performance characteristics. The
    implementations in this package have no dependencies other than those
    commonly bundled with Haskell compilers.
category: Data Structures
abi: 62e9ec534ac3e1fa7c0e843feaa544f2
exposed: True
exposed-modules:
    Data.Edison.Assoc.AssocList Data.Edison.Assoc.Defaults
    Data.Edison.Assoc.PatriciaLoMap Data.Edison.Assoc.StandardMap
    Data.Edison.Assoc.TernaryTrie Data.Edison.Coll.Defaults
    Data.Edison.Coll.EnumSet Data.Edison.Coll.LazyPairingHeap
    Data.Edison.Coll.LeftistHeap Data.Edison.Coll.MinHeap
    Data.Edison.Coll.SkewHeap Data.Edison.Coll.SplayHeap
    Data.Edison.Coll.StandardSet Data.Edison.Coll.UnbalancedSet
    Data.Edison.Concrete.FingerTree Data.Edison.Seq.BankersQueue
    Data.Edison.Seq.BinaryRandList Data.Edison.Seq.BraunSeq
    Data.Edison.Seq.Defaults Data.Edison.Seq.FingerSeq
    Data.Edison.Seq.JoinList Data.Edison.Seq.MyersStack
    Data.Edison.Seq.RandList Data.Edison.Seq.RevSeq
    Data.Edison.Seq.SimpleQueue Data.Edison.Seq.SizedSeq
import-dirs: /usr/lib/ghc-8.4.2/site-local/EdisonCore-1.3.2.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/EdisonCore-1.3.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/EdisonCore-1.3.2.1
hs-libraries: HSEdisonCore-1.3.2.1-6yqPau7HF7PLI1sbKMpaCS
depends:
    base-4.11.1.0 mtl-2.2.2 QuickCheck-2.11.3-4bkq8vcRuH33iMSCEtmKx6
    EdisonAPI-1.3.1-95fDYXS0D7a74bXECwc4er containers-0.5.11.0
    array-0.5.2.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             mtl-2.2.2=a7bec7c72de63625528e8aa4479db2c8
             QuickCheck-2.11.3-4bkq8vcRuH33iMSCEtmKx6=329f1c9cae18d78e8febe9289607fdb9
             EdisonAPI-1.3.1-95fDYXS0D7a74bXECwc4er=8c6f2dce53581083a8378785ce53be92
             containers-0.5.11.0=f8334bacfaf0e925ca7b24fb26fb2e66
             array-0.5.2.0=59560c027ff6ea5b7e467a38c579b575
haddock-interfaces: /usr/share/doc/haskell-edisoncore/html/EdisonCore.haddock
haddock-html: /usr/share/doc/haskell-edisoncore/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-edisoncore-1.3.2.1-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-edisoncore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: EdisonCore
version: 1.3.2.1
id: EdisonCore-1.3.2.1-IJ6FAB5YEPU2qvmSD9COmf
key: EdisonCore-1.3.2.1-IJ6FAB5YEPU2qvmSD9COmf
license: MIT
maintainer: robdockins AT fastmail DOT fm
author: Chris Okasaki
stability: Stable
homepage: http://rwd.rdockins.name/edison/home/
synopsis: A library of efficient, purely-functional data structures (Core Implementations)
description:
    This package provides the core Edison data structure implementations,
    including multiple sequence, set, bag, and finite map concrete
    implementations with various performance characteristics. The
    implementations in this package have no dependencies other than those
    commonly bundled with Haskell compilers.
category: Data Structures
abi: 20460e983b6933657c3095566291f34a
exposed: True
exposed-modules:
    Data.Edison.Assoc.AssocList Data.Edison.Assoc.Defaults
    Data.Edison.Assoc.PatriciaLoMap Data.Edison.Assoc.StandardMap
    Data.Edison.Assoc.TernaryTrie Data.Edison.Coll.Defaults
    Data.Edison.Coll.EnumSet Data.Edison.Coll.LazyPairingHeap
    Data.Edison.Coll.LeftistHeap Data.Edison.Coll.MinHeap
    Data.Edison.Coll.SkewHeap Data.Edison.Coll.SplayHeap
    Data.Edison.Coll.StandardSet Data.Edison.Coll.UnbalancedSet
    Data.Edison.Concrete.FingerTree Data.Edison.Seq.BankersQueue
    Data.Edison.Seq.BinaryRandList Data.Edison.Seq.BraunSeq
    Data.Edison.Seq.Defaults Data.Edison.Seq.FingerSeq
    Data.Edison.Seq.JoinList Data.Edison.Seq.MyersStack
    Data.Edison.Seq.RandList Data.Edison.Seq.RevSeq
    Data.Edison.Seq.SimpleQueue Data.Edison.Seq.SizedSeq
import-dirs: /usr/lib/ghc-8.6.1/site-local/EdisonCore-1.3.2.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/EdisonCore-1.3.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/EdisonCore-1.3.2.1
hs-libraries: HSEdisonCore-1.3.2.1-IJ6FAB5YEPU2qvmSD9COmf
depends:
    EdisonAPI-1.3.1-IEeVeuMM4NbBkXuVWfeYgY
    QuickCheck-2.11.3-BDoyaQh2Mcq3pIdI4VETKc array-0.5.2.0
    base-4.12.0.0 containers-0.6.0.1 mtl-2.2.2
haddock-interfaces: /usr/share/doc/haskell-edisoncore/html/EdisonCore.haddock
haddock-html: /usr/share/doc/haskell-edisoncore/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
